@@ -3,30 +3,30 @@
 ## RSP source document: './R.devices-overview.tex.rsp'
 ## Metadata 'title': 'R.devices overview'
 ## Metadata 'author': 'Henrik Bengtsson'
-## Metadata 'keywords': 'devices, graphics, plots, figures'
 ## Metadata 'engine': 'R.rsp::rsp'
+## Metadata 'keywords': 'devices, graphics, plots, figures'
 ###########################################################################
 
 t0 <- Sys.time()
-library("R.devices");
+library("R.devices")
 R.rsp <- R.oo::Package("R.rsp")
 withCapture <- R.utils::withCapture
 hpaste <- R.utils::hpaste
 
-devOptions("png", width=840);
+devOptions("png", width=840)
 devOptions("png", field="fullname") # Better for LaTeX
-options(width=85);
-options(digits=3);
-options(str=strOptions(strict.width="cut"));
+options(width=85)
+options(digits=3)
+options(str=strOptions(strict.width="cut"))
 R.rsp$version
 R.rsp$author
 format(as.Date(R.devices$date), format="%B %d, %Y")
-envir <- getNamespace("R.devices");
-tos <- ls(pattern="^to[A-Z][a-zA-Z]+", envir=envir);
-tos <- sprintf("%s()", tos);
+envir <- getNamespace("R.devices")
+tos <- ls(pattern="^to[A-Z][a-zA-Z]+", envir=envir)
+tos <- sprintf("%s()", tos)
 hpaste(sprintf("\\code{%s}", tos), maxHead=Inf, lastCollapse=", and ")
 toPDF("MyGaussianDensity", aspectRatio=0.6, {
-   curve(dnorm, from=-5, to=+5);
+   curve(dnorm, from=-5, to=+5)
   })
 devOptions("png", reset=TRUE)
 withCapture({
